derive_address

Function derive_address 

pub fn derive_address(public_key: &[u8], scheme: u8) -> AccountAddress
Derives an account address from a public key and scheme.

For most accounts, the address equals the authentication key.