pub struct Bls12381ProofOfPossession { /* private fields */ }Available on crate feature
bls only.Expand description
A BLS12-381 proof of possession.
A proof of possession (PoP) proves ownership of the private key corresponding
to a public key. This prevents rogue key attacks in aggregate signature schemes.
Implementations
Sourceimpl Bls12381ProofOfPossession
impl Bls12381ProofOfPossession
Sourcepub fn from_bytes(bytes: &[u8]) -> AptosResult<Self>
pub fn from_bytes(bytes: &[u8]) -> AptosResult<Self>
Creates a proof of possession from compressed bytes (96 bytes).
Errors
Returns an error if the bytes length is not 96 bytes or if the proof of possession deserialization fails.
Sourcepub fn from_hex(hex_str: &str) -> AptosResult<Self>
pub fn from_hex(hex_str: &str) -> AptosResult<Self>
Creates a proof of possession from a hex string.
Errors
Returns an error if hex decoding fails or if the resulting bytes are invalid.
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Returns the proof of possession as compressed bytes (96 bytes).
Sourcepub fn verify(&self, public_key: &Bls12381PublicKey) -> AptosResult<()>
pub fn verify(&self, public_key: &Bls12381PublicKey) -> AptosResult<()>
Verifies this proof of possession against a public key.
Returns Ok(()) if the PoP is valid, or an error if invalid.
Errors
Returns an error if proof of possession verification fails.