pub struct Bls12381PublicKey { /* private fields */ }bls only.Expand description
A BLS12-381 public key.
Implementations
Sourceimpl Bls12381PublicKey
impl Bls12381PublicKey
Sourcepub fn from_bytes(bytes: &[u8]) -> AptosResult<Self>
pub fn from_bytes(bytes: &[u8]) -> AptosResult<Self>
Creates a public key from compressed bytes (48 bytes).
Errors
Returns an error if the bytes length is not 48 bytes or if the key deserialization fails.
Sourcepub fn from_hex(hex_str: &str) -> AptosResult<Self>
pub fn from_hex(hex_str: &str) -> AptosResult<Self>
Creates a public key from a hex string.
Errors
Returns an error if hex decoding fails or if the resulting bytes are invalid.
Sourcepub fn verify(
&self,
message: &[u8],
signature: &Bls12381Signature,
) -> AptosResult<()>
pub fn verify( &self, message: &[u8], signature: &Bls12381Signature, ) -> AptosResult<()>
Sourceimpl Bls12381PublicKey
impl Bls12381PublicKey
Sourcepub fn aggregate(
public_keys: &[&Bls12381PublicKey],
) -> AptosResult<Bls12381PublicKey>
pub fn aggregate( public_keys: &[&Bls12381PublicKey], ) -> AptosResult<Bls12381PublicKey>
Aggregates multiple public keys into a single aggregated public key.
The aggregated public key can be used to verify an aggregated signature.
WARNING: This assumes all public keys have had their proofs-of-possession verified.
Errors
Returns an error if the list of public keys is empty or if aggregation fails.