pub fn derive_address(public_key: &[u8], scheme: u8) -> AccountAddressExpand description
Derives an account address from a public key and scheme.
For most accounts, the address equals the authentication key.
pub fn derive_address(public_key: &[u8], scheme: u8) -> AccountAddressDerives an account address from a public key and scheme.
For most accounts, the address equals the authentication key.