pub struct Bls12381Signature { /* private fields */ }bls only.Expand description
A BLS12-381 signature.
Implementations
Sourceimpl Bls12381Signature
impl Bls12381Signature
Sourcepub fn from_bytes(bytes: &[u8]) -> AptosResult<Self>
pub fn from_bytes(bytes: &[u8]) -> AptosResult<Self>
Creates a signature from compressed bytes (96 bytes).
Errors
Returns an error if the bytes length is not 96 bytes or if the signature deserialization fails.
Sourcepub fn from_hex(hex_str: &str) -> AptosResult<Self>
pub fn from_hex(hex_str: &str) -> AptosResult<Self>
Creates a signature from a hex string.
Errors
Returns an error if hex decoding fails or if the resulting bytes are invalid.
Sourceimpl Bls12381Signature
impl Bls12381Signature
Sourcepub fn aggregate(
signatures: &[&Bls12381Signature],
) -> AptosResult<Bls12381Signature>
pub fn aggregate( signatures: &[&Bls12381Signature], ) -> AptosResult<Bls12381Signature>
Aggregates multiple signatures into a single aggregated signature.
The aggregated signature can be verified against an aggregated public key for the same message, or against individual public keys for different messages.
Errors
Returns an error if the list of signatures is empty or if aggregation fails.